@@ -33,7 +33,7 @@
 
 typedef enum {
 	GCONF_KEY_EDITOR_NEW_KEY,
-	GCONF_KEY_EDITOR_EDIT_KEY,
+	GCONF_KEY_EDITOR_EDIT_KEY
 } GConfKeyEditorAction;
 
 typedef struct _GConfKeyEditor GConfKeyEditor;
@@ -60,7 +60,7 @@ struct _GConfKeyEditor {
 	GtkWidget *list_widget;
 	GtkListStore *list_model;
 	GtkWidget *list_type_menu;
-	GtkWidget *remove_button, *go_up_button, *go_down_button;
+	GtkWidget *edit_button, *remove_button, *go_up_button, *go_down_button;
 
 };
 
